/***********************************************************************************
* Copyright (C) 2009 Vojtech 'vogo' Gondzala <vojtech.gondzala@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
***********************************************************************************/

#include "plasma_applet_hdaps_monitor.h"

#include <QPainter>
#include <QDir>
#include <QTimer>

#include <QString>
#include <QStringList>

#include <Plasma/Theme>
#include <Plasma/ToolTipManager>

PlasmaHdapsMonitor::PlasmaHdapsMonitor(QObject *parent, const QVariantList &args)
	: Plasma::Applet(parent, args),
	m_iconHdd("drive-harddisk"),
	m_iconRun("media-playback-start"),
	m_iconStop("media-playback-pause"),
	m_iconUnknown("dialog-warning"),
	m_status(UnknownHDAPS)
{
	setBackgroundHints(DefaultBackground);
	setAspectRatioMode(Plasma::Square);
}

PlasmaHdapsMonitor::~PlasmaHdapsMonitor()
{
}

void PlasmaHdapsMonitor::init()
{
	connect(this, SIGNAL(activate()), this, SLOT(showTip()));
	connect(&m_timer, SIGNAL(timeout()), this, SLOT(doUpdate()));
	m_timer.start(500);
}

void PlasmaHdapsMonitor::paintInterface(QPainter *p,
                                 const QStyleOptionGraphicsItem *option,
                                 const QRect& contentsRect )
{
	Q_UNUSED(option);

	p->setRenderHint(QPainter::SmoothPixmapTransform);
	p->setRenderHint(QPainter::Antialiasing);

	int size = contentsRect.height();
	p->drawPixmap(contentsRect.topLeft(), m_iconHdd.pixmap(size, size));

	size /= 2;
	switch(m_status) {
		case RunHDAPS:
			p->drawPixmap(contentsRect.topLeft(), m_iconRun.pixmap(size, size));
			break;
		case StopHDAPS:
			p->drawPixmap(contentsRect.topLeft(), m_iconStop.pixmap(size, size));
			break;
		default:
			p->drawPixmap(contentsRect.topLeft(), m_iconUnknown.pixmap(size, size));
	}
}

void PlasmaHdapsMonitor::doUpdate()
{
	getStatus();
	update();
}

void PlasmaHdapsMonitor::showTip()
{
	if(Plasma::ToolTipManager::self()->isVisible(this)) {
		Plasma::ToolTipManager::self()->hide(this);
	} else {	
		Plasma::ToolTipManager::self()->show(this);
	}
}

void PlasmaHdapsMonitor::getStatus()
{
	QString toolTipText = i18n("Not supported") + "<br>";
	m_status = UnknownHDAPS;

	if(m_sysFS.hasHDAPS()) {
		toolTipText = "<b>" + i18n("Devices") + "</b><br>";
		QStringList deviceList = m_sysFS.deviceList();
		if(deviceList.count() > 0) {
			m_status = RunHDAPS;
			for(int i = 0; i < deviceList.count(); i++) {
				QString device = deviceList[i];
				QString status;
				int time = m_sysFS.unloadHeads(device);
				if (time > 0) {
					status = i18n("Parked (%1 s remaining)").arg(time / 1000.0, 0, 'f', 1);
					m_status = StopHDAPS;
				} else {
					status = i18n("Running");
				}
				toolTipText += QString("%1: %2<br>").arg(device, status);
			}
		} else {
			toolTipText = i18n("No devices found") + "<br>";
		}
		toolTipText += "<br><b>" + i18n("Activity") + "</b><br>";
		toolTipText += i18n("Keyboard: %1").arg(m_sysFS.keyboardActivity() ? i18n("Yes") : i18n("No")) + "<br>";
		toolTipText += i18n("Mouse: %1").arg(m_sysFS.mouseActivity() ? i18n("Yes") : i18n("No")) + "<br>";
		toolTipText += i18n("Position: %1").arg(m_sysFS.position());
	}
	Plasma::ToolTipManager::self()->setContent(this,
		Plasma::ToolTipContent(i18n("HDAPS status"),
		toolTipText, m_iconHdd));
}

#include "plasma_applet_hdaps_monitor.moc"
