/***********************************************************************************
* Copyright (C) 2009 Vojtech 'vogo' Gondzala <vojtech.gondzala@gmail.com>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
***********************************************************************************/

#include <QDir>
#include "sysfs_parse.h"

SysFsParse::SysFsParse()
{
}

SysFsParse::~SysFsParse()
{
}

bool SysFsParse::hasHDAPS()
{
	QDir dir("/sys/devices/platform/hdaps");
	return dir.isReadable();
}

QStringList SysFsParse::deviceList()
{
	QStringList deviceList;
	QDir sysBlock("/sys/block", "[hs]d*", QDir::IgnoreCase, QDir::Dirs);
	for(int i = 0; i < (int)sysBlock.count(); i++) {
		QString device = QString("/sys/block/") + sysBlock[i] + "/device/unload_heads";
		deviceList.append(sysBlock[i]);
	}
	return deviceList;
}

int SysFsParse::unloadHeads(QString device)
{
	return fileInt("/sys/block/" + device + "/device/unload_heads");
}

bool SysFsParse::keyboardActivity()
{
  return fileInt("/sys/devices/platform/hdaps/keyboard_activity");
}

bool SysFsParse::mouseActivity()
{
  return fileInt("/sys/devices/platform/hdaps/mouse_activity");
}

QString SysFsParse::position()
{
	QFile file("/sys/devices/platform/hdaps/position");
	if (file.exists() && file.open(QIODevice::ReadOnly | QIODevice::Text)) {
		return QString(file.readLine());
	}
	return "n/a";
}

int SysFsParse::fileInt(QString path)
{
	QFile file(path);
	if (file.exists() && file.open(QIODevice::ReadOnly | QIODevice::Text)) {
		return QString(file.readLine()).toInt();
	}
	return false;
}
